@@ -758,8 +758,8 @@ render_background (BGApplier *bg_applier, const BGPreferences *prefs)
 static void
 render_wallpaper (BGApplier *bg_applier, const BGPreferences *prefs) 
 {
-	GdkRectangle  src_geom;
-	GdkRectangle  dest_geom;
+	GdkRectangle  src_geom = { 0, };
+	GdkRectangle  dest_geom = { 0, };
 	GdkRectangle  virtual_geom;
 	GdkPixbuf    *prescaled_pixbuf = NULL;
 	guint         alpha;
@@ -1012,15 +1012,8 @@ get_geometry (wallpaper_type_t  wallpaper_type,
 	gint pwidth, pheight;
 	gint st = 0;
 
-	if (field_geom->width != virtual_geom->width)
-		xfactor = (gdouble) field_geom->width / (gdouble) virtual_geom->width;
-	else
-		xfactor = 1.0;
-
-	if (field_geom->height != virtual_geom->height)
-		yfactor = (gdouble) field_geom->height / (gdouble) virtual_geom->height;
-	else
-		yfactor = 1.0;
+	xfactor = (gdouble) field_geom->width / (gdouble) virtual_geom->width;
+	yfactor = (gdouble) field_geom->height / (gdouble) virtual_geom->height;
 
 	pwidth = gdk_pixbuf_get_width (pixbuf);
 	pheight = gdk_pixbuf_get_height (pixbuf);
@@ -1091,6 +1084,27 @@ get_geometry (wallpaper_type_t  wallpaper_type,
 
 		break;
 
+	case WPTYPE_ZOOM:
+		asp = (gdouble) pwidth / (gdouble) virtual_geom->width;
+
+		if (asp > (gdouble) pheight / virtual_geom->height) {
+			src_geom->width = pheight * virtual_geom->width / virtual_geom->height;
+			src_geom->height = pheight;
+			src_geom->x = (pwidth - src_geom->width) / 2;
+			src_geom->y = 0;
+		} else {
+			src_geom->width = pwidth;
+			src_geom->height = pwidth * virtual_geom->height / virtual_geom->width;
+			src_geom->x = 0;
+			src_geom->y = (pheight - src_geom->height) / 2;
+		}
+
+		dest_geom->x = dest_geom->y = 0;
+		dest_geom->width = field_geom->width;
+		dest_geom->height = field_geom->height;
+
+		break;
+
 	case WPTYPE_STRETCHED:
 		dest_geom->width = field_geom->width;
 		dest_geom->height = field_geom->height;
@@ -1624,8 +1638,8 @@ is_nautilus_running (void)
 	    bytes_after == 0 &&
 	    actual_format == 8 &&
 	    data != NULL &&
-	    !strcmp (data, "desktop_window") &&
-	    !strcmp (data + strlen (data) + 1, "Nautilus"))
+	    !strcmp ((char *)data, "desktop_window") &&
+	    !strcmp ((char *)data + strlen ((char *)data) + 1, "Nautilus"))
 		running = TRUE;
 	else
 		running = FALSE;
