@@ -22,7 +22,7 @@
    Author: Darin Adler <darin@bentspoon.com>
 */
 
-#include "nautilus-directory.h"
+#include <libnautilus-private/nautilus-directory.h>
 
 /* Interface for file metadata. */
 gboolean nautilus_directory_is_metadata_read	      (NautilusDirectory *directory);
@@ -79,5 +79,3 @@ void	 nautilus_directory_rename_directory_metadata      (NautilusDirectory *dire
 
 void nautilus_directory_register_metadata_monitor   (NautilusDirectory *directory);
 void nautilus_directory_unregister_metadata_monitor (NautilusDirectory *directory);
-
-void	 nautilus_directory_use_self_contained_metafile_factory (void);
