@@ -64,18 +64,21 @@ struct _NautilusTreeViewDragDestClass {
 				 GdkDragAction action,
 				 int x,
 				 int y);
-	void (* handle_url)     (NautilusTreeViewDragDest *dest,
-				 char *url,
+	void (* handle_netscape_url) (NautilusTreeViewDragDest *dest,
+				 const char *url,
+				 const char *target_uri,
 				 GdkDragAction action,
 				 int x,
 				 int y);
 	void (* handle_uri_list) (NautilusTreeViewDragDest *dest,
-				  char *uri_list,
+				  const char *uri_list,
+				  const char *target_uri,
 				  GdkDragAction action,
 				  int x,
 				  int y);
 	void (* handle_text)    (NautilusTreeViewDragDest *dest,
-				  char *text,
+				  const char *text,
+				  const char *target_uri,
 				  GdkDragAction action,
 				  int x,
 				  int y);
